# -*- coding: utf-8 -*-

"""Top-level package for Crackhash."""

__author__ = '5h4d0wb0y'
__email__ = '5h4d0wb0y@protonmail.com'
__version__ = '1.0.1'
__description__ = 'Crackhash is a tool that try to crack different types of hashes using free online services.'
__copyright__ = "2019, 5h4dowboy"